@@ -1,5 +1,5 @@
 package WebAPI::DBIC;
-$WebAPI::DBIC::VERSION = '0.001005'; # TRIAL
+$WebAPI::DBIC::VERSION = '0.001008'; # TRIAL
 use strict; # keep our kwalitee up!
 use warnings;
 1;
@@ -16,7 +16,7 @@ WebAPI::DBIC
 
 =head1 VERSION
 
-version 0.001005
+version 0.001008
 
 =head1 DESCRIPTION
 
@@ -36,6 +36,10 @@ L<Path::Router> as the router. (We aim to support other routers soon.)
 
 * Built as fine-grained roles for maximum reusability and extensibility
 
+* Integrates with other L<Plack> based applications.
+
+* The resource roles can be added to your existing application
+
 * A built-in copy of the generic HAL API browser application
 
 * An example .psgi file that gives you an instant web service for any DBIx::Class schema
@@ -98,13 +102,12 @@ DBIx::Class schema. This is what makes the API discoverable and browseable.
 
 =head1 NAME
 
-WebAPI::DBIC - A composable RESTful JSON+HAL API to DBIx::Class schemas using roles, Web::Machine and Path::Router
+WebAPI::DBIC - A composable RESTful JSON+HAL API to DBIx::Class schemas using roles and Web::Machine
 
 =head1 STATUS
 
 The WebAPI::DBIC code has been in production use since early 2013, however it's
-only recently been open sourced (July 2014) so it's still lacking in
-documentation, tests etc.
+only recently been open sourced (July 2014) so it's still lacking in documentation.
 
 It's also likely to undergo a period of refactoring now there are more
 developers contributing and the code is being applied to more domains.
@@ -191,35 +194,49 @@ have their values JSON decoded, so they can be arbitrary data structures.
 
 =head2 Resource Classes
 
-To make building typical applications easier, WebAPI::DBIC provides three
+To make building typical applications easier, WebAPI::DBIC provides four
 pre-defined resource classes:
 
-L<WebAPI::DBIC::Resource::GenericItemDBIC> for resources represented by an
-individual DBIx::Class row.
+L<WebAPI::DBIC::Resource::GenericCore> is a base class that consumes all the
+general-purpose resource roles.
 
-L<WebAPI::DBIC::Resource::GenericSetDBIC> for resources represented by a
-DBIx::Class result set.
+L<WebAPI::DBIC::Resource::GenericItem> subclasses GenericCore and consumes
+extra roles for resources represented by an individual DBIx::Class row.
 
-L<WebAPI::DBIC::Resource::GenericItemInvoke> for resources that represent a
-specific method call on an item resource.
+L<WebAPI::DBIC::Resource::GenericSet> subclasses GenericCore and consumes extra
+roles for resources represented by a DBIx::Class result set.
+
+L<WebAPI::DBIC::Resource::GenericItemInvoke> subclasses GenericCore and
+consumes extra roles for resources that represent a specific method call on an
+item resource.
 
 These classes are I<very> simple because all the work is done by the various
 roles they consume. For example, here's the entire code for
-L<WebAPI::DBIC::Resource::GenericItemDBIC>:
+L<WebAPI::DBIC::Resource::GenericCore>:
 
-    package WebAPI::DBIC::Resource::GenericItemDBIC;
+    package WebAPI::DBIC::Resource::GenericCore;
     use Moo;
-    extends 'WebAPI::DBIC::Resource::Base'; # is just Web::Machine::Resource
+    extends 'WebAPI::DBIC::Resource::Base';
     with    'WebAPI::DBIC::Role::JsonEncoder',
             'WebAPI::DBIC::Role::JsonParams',
             'WebAPI::DBIC::Resource::Role::Router',
             'WebAPI::DBIC::Resource::Role::Identity',
+            'WebAPI::DBIC::Resource::Role::Relationship',
             'WebAPI::DBIC::Resource::Role::DBIC',
             'WebAPI::DBIC::Resource::Role::DBICException',
             'WebAPI::DBIC::Resource::Role::DBICAuth',
             'WebAPI::DBIC::Resource::Role::DBICParams',
-            'WebAPI::DBIC::Resource::Role::Item',
-            'WebAPI::DBIC::Resource::Role::ItemWritable',
+            ;
+    1;
+
+and L<WebAPI::DBIC::Resource::GenericItem>:
+
+    package WebAPI::DBIC::Resource::GenericSet;
+    use Moo;
+    extends 'WebAPI::DBIC::Resource::GenericCore';
+    with    'WebAPI::DBIC::Resource::Role::SetRender',
+            'WebAPI::DBIC::Resource::Role::Set',
+            'WebAPI::DBIC::Resource::Role::SetWritable',
             ;
     1;
 
@@ -229,24 +246,88 @@ A few other classes are provided:
 
 L<WebAPI::DBIC::Util.pm> provides a few general utilities.
 
-L<WebAPI::DBIC::Machine.pm> a subclass of L<Web::Machine>.
-
 L<WebAPI::DBIC::WebApp> - this is the main app class and is most likely to
-change in the near future so isn't documented yet.
+change in the near future so isn't documented much yet.
 
-=head1 LIMITATIONS AND OUTSTANDING DESIGN ISSUES
+=head1 TRANSPARENCY
 
-Multi-column identities (e.g. primary keys) are not fully supported yet. Simple
-integer cases will work but the url path format is likely to change.
+WebAPI::DBIC aims to be a fairly 'transparent' layer between your
+L<DBIx::Class> schema and the JSON that's generated and received.
 
-Column inflation, e.g. DateTime, is not worked out yet.
+So it's the responibility of your schema to return data in the format you want
+in your generated URLs and JSON, and to accept data in the format that arrives
+in requests from clients.
 
-The only supported router is Path::Router at the moment.
+For an example of how to handle dates using L<DateTime> nicely, see:
 
-See also https://metacpan.org/pod/distribution/WebAPI-DBIC/NOTES.pod
-and https://github.com/timbunce/WebAPI-DBIC/issues
+  https://blog.afoolishmanifesto.com/posts/solution-on-how-to-serialize-dates-nicely/
 
-If there's anything you specifically need, just ask!
+=head1 COMPARISONS
+
+This section provides links to similar modules with a few notes about how they
+differ from WebAPI::DBIC.
+
+=head2 ... others? ...
+
+=head2 App::AutoCRUD
+
+L<App::AutoCRUD> provides an automatically generated I<HTML> interface to a
+database, including search forms. It can export data in various formats
+including JSON but isn't designed as a JSON API, so it's not directly
+comparable to WebAPI::DBIC. See also L<RapidApp>.
+
+App::AutoCRUD doesn't use DBIx::Class, it uses DBIx::DataModel (a UML-based ORM
+framework), but creates the model on the fly. That doesn't let you build
+business logic into the schema model the way you can with DBIx::Class.
+
+=head2 RapidApp
+
+To quote the documentation: L<RapidApp> is an extension to L<Catalyst> - the
+Perl MVC framework. It provides a feature-rich extended development stack, as
+well as easy access to common out-of-the-box application paradigms, such as
+powerful CRUD-based front-ends for DBIx::Class models, user access and
+authorization, RESTful URL navigation schemes, pure Ajax interfaces with no
+browser page loads, templating engine with front-side CMS features, declarative
+configuration layers, and more.
+
+It's not designed as a JSON API and doesn't use HAL, so it's not directly
+comparable to WebAPI::DBIC.
+
+=head1 INTEGRATIONS
+
+This section provides information on how to integrate WebAPI::DBIC with
+existing applications.
+
+=head2 Catalyst
+
+As with any PSGI application, WebAPI::DBIC can integrate into Catalyst fairly
+simply with L<Catalyst::Action::FromPSGI>.  Here's an example integration:
+
+ package MyApp::Controller::HelloName;
+
+ use base 'Catalyst::Controller';
+
+ sub api : Path('/api') ActionClass('FromPSGI') {
+   my ($self, $c) = @_;
+
+   WebAPI::DBIC::WebApp->new({
+     schema   => $c->model('DB')->schema,
+     writable => 0,            # set true if desired
+     http_auth_type => 'none', # will use Catalysts' auth for the given path
+                               # consider leveraging chaining or another
+                               # ActionRole for auth
+   })->to_psgi_app
+ }
+
+=head2 Dancer
+
+I<I'd welcome any information you could contribute here.>
+
+=head2 Mojolicious
+
+I<I'd welcome any information you could contribute here.>
+
+=head2 ...
 
 =head1 HOW TO GET HELP
 
@@ -262,6 +343,11 @@ If there's anything you specifically need, just ask!
 
 =back
 
+See also https://metacpan.org/pod/distribution/WebAPI-DBIC/NOTES.pod
+and https://github.com/timbunce/WebAPI-DBIC/issues
+
+If there's anything you specifically need, just ask!
+
 =head1 CREDITS
 
 Stevan Little gets top billing for creating L<Web::Machine> and L<Path::Router>
@@ -313,7 +399,7 @@ http://tools.ietf.org/html/rfc6570
 
     GET ~/resources/:id
 
-returns 
+returns
 
     {
         _links: { ... }  # optional
@@ -355,7 +441,9 @@ would include
 
 The "relation" links describe the relationships this resource has with other resources.
 
-TBD Currently only 1-1 relationships (e.g., belongs_to) are included. Also see L</prefetch>.
+Currently only 1-1 relationships (e.g., belongs_to) are and simple 1-N
+(has_many) relationships are supported and get C<_links>.
+Also see L</prefetch>.
 
 =head2 GET Item - Optional Parameters
 
@@ -421,12 +509,12 @@ allows paging of the set but doesn't include links in the embedded resources.
 
     GET ~/ecosystems
 
-returns 
+returns
 
     {
         _links: { ... },  # optional
         _meta: { ... },   # optional
-        _embedded: { 
+        _embedded: {
             ecosystems => [
                 { ... }, ...
             ]
