@@ -1,5 +1,6 @@
 package WebAPI::DBIC::Resource::Role::Item;
-$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.001005'; # TRIAL
+$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.001008'; # TRIAL
+
 use Moo::Role;
 
 
@@ -55,7 +56,18 @@ WebAPI::DBIC::Resource::Role::Item
 
 =head1 VERSION
 
-version 0.001005
+version 0.001008
+
+=head1 DESCRIPTION
+
+Handles GET and HEAD requests for requests representing individual resources,
+e.g. a single row of a database table.
+
+Supports the C<application/hal+json> and C<application/json> content types.
+
+=head1 NAME
+
+WebAPI::DBIC::Resource::Role::Item - methods related to handling requests for item resources
 
 =head1 AUTHOR
 
