@@ -1,5 +1,6 @@
 package WebAPI::DBIC::Resource::Role::ItemWritable;
-$WebAPI::DBIC::Resource::Role::ItemWritable::VERSION = '0.001005'; # TRIAL
+$WebAPI::DBIC::Resource::Role::ItemWritable::VERSION = '0.001008'; # TRIAL
+
 use Carp qw(croak confess);
 use Devel::Dwarn;
 
@@ -16,6 +17,15 @@ requires 'response';
 requires 'path_for_item';
 
 
+# By default the DBIx::Class::Row update() call will only update the
+# columns where %$hal contains different values to the ones in $item.
+# This is usually a useful optimization but not always. So we provide
+# a way to disable it on individual resources.
+has skip_dirty_check => (
+    is => 'rw',
+);
+
+
 sub content_types_accepted { return [
     {'application/hal+json' => 'from_plain_json'},
     {'application/json'     => 'from_plain_json'}
@@ -91,9 +101,22 @@ sub _update_embedded_resources {
         # XXX perhaps save $subitem to optimise prefetch handling?
     }
 
+    # By default the DBIx::Class::Row update() call below will only update the
+    # columns where %$hal contains different values to the ones in $item
+    # This is usually a useful optimization but not always. So we provide
+    # a way to disable it on individual resources.
+    if ($self->skip_dirty_check) {
+        $item->make_column_dirty($_) for keys %$hal;
+    }
+
+    # Note that update() calls set_inflated_columns()
+    $item->update($hal);
+
     # XXX discard_changes causes a refetch of the record for prefetch
     # perhaps worth trying to avoid the discard if not required
-    return $item->update($hal)->discard_changes();
+    $item->discard_changes();
+
+    return $item;
 }
 
 
@@ -136,7 +159,7 @@ sub update_resource {
             my $meta     = delete $hal->{_meta};
             my $embedded = delete $hal->{_embedded} && die "_embedded not supported here (yet?)\n";
 
-            $item = $self->set->create($hal);
+            $item = $self->set->create($hal); # handles deflation
 
             $self->response->header('Location' => $self->path_for_item($item))
                 unless $old_item; # set Location and thus 201 if Created not modified
@@ -170,7 +193,11 @@ WebAPI::DBIC::Resource::Role::ItemWritable
 
 =head1 VERSION
 
-version 0.001005
+version 0.001008
+
+=head1 NAME
+
+WebAPI::DBIC::Resource::Role::ItemWritable - methods handling requests to update item resources
 
 =head1 AUTHOR
 
