@@ -1,5 +1,6 @@
 package WebAPI::DBIC::Role::JsonEncoder;
-$WebAPI::DBIC::Role::JsonEncoder::VERSION = '0.001005'; # TRIAL
+$WebAPI::DBIC::Role::JsonEncoder::VERSION = '0.001008'; # TRIAL
+
 use JSON::MaybeXS qw(JSON);
 
 use Moo::Role;
@@ -7,7 +8,6 @@ use Moo::Role;
 
 has _json_encoder => (
    is => 'ro',
-   lazy => 1,
    builder => '_build_json_encoder',
    handles => {
       encode_json => 'encode',
@@ -31,7 +31,11 @@ WebAPI::DBIC::Role::JsonEncoder
 
 =head1 VERSION
 
-version 0.001005
+version 0.001008
+
+=head1 NAME
+
+WebAPI::DBIC::Resource::Role::JsonEncoder - provides encode_json and decode_json methods
 
 =head1 AUTHOR
 
