@@ -1,5 +1,10 @@
 package WebAPI::HTTP::Throwable::Factory;
-$WebAPI::HTTP::Throwable::Factory::VERSION = '0.001005'; # TRIAL
+$WebAPI::HTTP::Throwable::Factory::VERSION = '0.001008'; # TRIAL
+
+# I'm not sure what value there is here, but maybe I'm just forgetting the goodness.
+# Exception handling probably needs to be rethought.
+# See also WebAPI::HTTP::Throwable::Role::JSONBody
+
 use strict;
 use warnings;
 
@@ -18,19 +23,23 @@ sub extra_roles {
 
 sub throw_bad_request {
     my ($class, $status, %opts) = @_;
-    cluck("bad status") unless $status =~ /^4\d\d$/;
+
+    cluck("bad status $status") unless $status =~ /^4\d\d$/;
     carp("throw_bad_request @_") if $ENV{WEBAPI_DBIC_DEBUG};
 
     # XXX TODO validations
     my $data = {
         errors => $opts{errors},
     };
+
     my $json_body = JSON->new->ascii->pretty->encode($data);
+
     # [ 'Content-Type' => 'application/hal+json' ],
     $class->throw( BadRequest => {
         status_code => $status,
         message => $json_body,
     });
+
     return;                     # not reached
 }
 
@@ -50,7 +59,17 @@ WebAPI::HTTP::Throwable::Factory
 
 =head1 VERSION
 
-version 0.001005
+version 0.001008
+
+=head1 DESCRIPTION
+
+Throw L<HTTP::Throwable> exceptions that contain JSON in the body.
+
+See also L<WebAPI::HTTP::Throwable::Role::JSONBody>.
+
+=head1 NAME
+
+WebAPI::HTTP::Throwable::Factory - methods to support throwing HTTP exceptions
 
 =head1 AUTHOR
 
